##### API Ninjas API

API Ninjas is a service which provides access to a large number of simple APIs. You'll need an API Key to use the service. You get 50K requests for free, after that you need to subscribe to a premium plan. With the free plan there is no support or commercial use.

In the context of NDR Core, API Ninjas APIs help you build test environments or demonstrate NDR Cores ability to get data from somewhere and display it in a pretty form.

###### Configure Access to an API Ninja API

- Go to api-ninjas.com and create an account.
- Find your API Key in your user settings and copy it.
- Go to api-ninjas.com/api and choose the API you want to use.
- For this example we're using the country API. (see api-ninjas.com/api/country). You see on the API detail page which parameters are supported/required. For the country API there are no required fields. We'll use `name` as search parameter in our example.
- Go to [[create new api conf]] and create your access to the selected API. You'll need the following settings:

###### Disclaimer

This API implementation is part of NDR Core. It is in no way affiliated with api-ninjas.com. Excessive use of api ninja APIs will need a payed plan with api-ninjas. NDR Core only gets results from this service. All rules and restrictions of api-ninjas.com still aply.